Repos / mcross / a067290e1b
commit a067290e1b034e498de101b1df7908ec1108b46f
Author: Bùi Thành Nhân <hi@imnhan.com>
Date:   Thu May 14 23:34:31 2020 +0700

    actually I like McRoss more

diff --git a/README.md b/README.md
index 026f941..d36eb82 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-McCross is a WIP [gemini://](https://gemini.circumlunar.space/) browser
+McRoss is a WIP [gemini://](https://gemini.circumlunar.space/) browser
 written in python and tkinter.
 
 It's developed against gemini://gemini.circumlunar.space/ because apparently
@@ -15,8 +15,8 @@
 # Installation
 
 ```sh
-pip install mccross
-mccross
+pip install mcross
+mcross
 ```
 
 # Deps
diff --git a/pyproject.toml b/pyproject.toml
index 97c39b0..1e5e006 100644
--- a/pyproject.toml
+++ b/pyproject.toml
@@ -1,15 +1,15 @@
 [tool.poetry]
-name = "mccross"
+name = "mcross"
 version = "0.1.1"
 description = "Do you remember www?"
 authors = ["nhanb <hi@imnhan.com>"]
 license = "MIT"
 packages = [
-    { include = "mccross", from = "src" },
+    { include = "mcross", from = "src" },
 ]
 
 [tool.poetry.scripts]
-mccross = "mccross:run"
+mcross = "mcross:run"
 
 [tool.poetry.dependencies]
 python = "^3.7"
diff --git a/src/mccross/__init__.py b/src/mcross/__init__.py
similarity index 100%
rename from src/mccross/__init__.py
rename to src/mcross/__init__.py
diff --git a/src/mccross/document.py b/src/mcross/document.py
similarity index 100%
rename from src/mccross/document.py
rename to src/mcross/document.py
diff --git a/src/mccross/gui/__init__.py b/src/mcross/gui/__init__.py
similarity index 100%
rename from src/mccross/gui/__init__.py
rename to src/mcross/gui/__init__.py
diff --git a/src/mccross/gui/controller.py b/src/mcross/gui/controller.py
similarity index 95%
rename from src/mccross/gui/controller.py
rename to src/mcross/gui/controller.py
index b040467..2edc5aa 100644
--- a/src/mccross/gui/controller.py
+++ b/src/mcross/gui/controller.py
@@ -13,7 +13,7 @@ def __init__(self):
         self.view.go_callback = self.go_callback
 
     def run(self):
-        self.root.title("McCross Browser")
+        self.root.title("McRoss Browser")
         self.root.geometry("800x600")
         self.root.mainloop()
 
diff --git a/src/mccross/gui/model.py b/src/mcross/gui/model.py
similarity index 96%
rename from src/mccross/gui/model.py
rename to src/mcross/gui/model.py
index 80b4678..6b08883 100644
--- a/src/mccross/gui/model.py
+++ b/src/mcross/gui/model.py
@@ -1,7 +1,7 @@
 from .. import document
 
 DEMO_TEXT = """\
 # Welcome to McCross Browser
 
 ## List
 
@@ -14,7 +14,7 @@
 
 ```
 [tool.poetry]
-name = "mccross"
+name = "mcross"
 version = "0.1.0"
 description = "Do you remember www?"
 authors = ["nhanb <hi@imnhan.com>"]
@@ -1,7 +1,7 @@
 
 DEMO_TEXT = """\
-# Welcome to McCross Browser
+# Welcome to McRoss Browser
 
 ## List
diff --git a/src/mccross/gui/view.py b/src/mcross/gui/view.py
similarity index 100%
rename from src/mccross/gui/view.py
rename to src/mcross/gui/view.py
diff --git a/src/mccross/gui/widgets.py b/src/mcross/gui/widgets.py
similarity index 100%
rename from src/mccross/gui/widgets.py
rename to src/mcross/gui/widgets.py
diff --git a/src/mccross/transport.py b/src/mcross/transport.py
similarity index 100%
rename from src/mccross/transport.py
rename to src/mcross/transport.py